@@ -69,9 +69,13 @@ def OAEParser():
     modes.add_argument('-p', '--parallel-batch', action='store', default=False,
                        help='''Use to specify a batch directory for parallel
                                processing.''')
-    modes.add_argument('-C', '--collection', action='store_true', default=False,
+    modes.add_argument('-C', '--collection', action='store', default=False,
+                       nargs='?', const='True',
                        help='''Use to combine all xml files in the local
-                               directory into a single ePub collection.''')
+                               directory into a single ePub collection.
+                               Typing a string after this flag will provide a
+                               title for the collection. If no title is given,
+                               the main script may ask for one.''')
     modes.add_argument('-cI', '--clear-image-cache', action='store_true',
                        default=False, help='''Clears the image cache''')
     modes.add_argument('-cC', '--clear-cache', action='store_true',
@@ -185,7 +189,7 @@ def batch_input(args, config=None):
             make_epub(parsed_article,
                       outdirect=output_name,
                       explicit_images=None,   # No explicit image path
-                      batch=False,
+                      batch=True,
                       config=config)
         except:
             error_file.write(item_path + '\n')
@@ -247,19 +251,26 @@ def collection_input(args, config=None):
     epub_base = os.path.join(CACHE_LOCATION, 'base_epub')
     shutil.copytree(epub_base, output_name)
     
-    toc = ncx.TocNCX(version=__version__, collection_mode=True)
-    myopf = opf.PLoSOPF(__version__, output_name, collection_mode=True, title=output_name)
+    if args.collection is True:
+        title = output_name
+    else:
+        title = args.collection
+    
+    toc = ncx.NCX(oae_version=__version__, location=output_name, collection_mode=True)
+    myopf = opf.OPF(location=output_name, collection_mode=True, title=title)
     
     #Now it is time to operate on each of the xml files
     for xml_file in xml_files:
         raw_name = u_input.local_input(xml_file)  # is this used?
         parsed_article = Article(xml_file)
+        toc.take_article(parsed_article)
+        myopf.take_article(parsed_article)
     
         if parsed_article.metadata.dtdVersion() == '2.0':  #Not supported
             print('Article published with JPTS DTDv2.0, not supported!')
             sys.exit(1)
         #Get the Digital Object Identifier
-        doi = parsed_article.getDOI()
+        doi = parsed_article.get_DOI()
         journal_doi, article_doi = doi.split('/')
         
         #Check for images
@@ -286,11 +297,10 @@ def collection_input(args, config=None):
         if journal_doi == '10.1371':  # PLoS's publisher DOI
             ops_doc = ops.OPSPLoS(parsed_article, output_name)
             #TODO: Workflow change, parse table of contents from OPS processed document
-            toc.parse_article(parsed_article)
-            myopf.parse_article(parsed_article)
-    toc.write(output_name)
+            
+    toc.write()
     myopf.write()
-    utils.epubZip(output_name)
+    utils.epub_zip(output_name)
     
 
     #Running epubcheck on the output verifies the validity of the ePub,
@@ -415,28 +425,19 @@ def make_epub(document, outdirect, explicit_images, batch, config=None):
         return
 
     #Get the Digital Object Identifier
-    DOI = document.getDOI()
+    DOI = document.get_DOI()
 
     #Get the images
     get_images(DOI, outdirect, explicit_images, config, document)
 
-    #Run content processing per publisher
-    if DOI.split('/')[0] == '10.1371':  # PLoS's publisher DOI
-        ops_doc = ops.OPSPLoS(document, outdirect)
-        #TODO: Workflow change, parse table of contents from OPS processed document
-        toc = ncx.TocNCX(__version__)
-        toc.parse_article(document)
-        toc.write(outdirect)
-        myopf = opf.PLoSOPF(__version__, outdirect, False)
-    elif DOI.split('/')[0] == '10.3389':  # Frontiers' publisher DOI
-        ops.OPSFrontiers(document, outdirect)
-        toc = ncx.TocNCX(__version__)
-        toc.parse_article(document)
-        toc.write(outdirect)
-        myopf = opf.FrontiersOPF(__version__, outdirect, False)
-    myopf.parse_article(document)
+    toc = ncx.NCX(__version__, outdirect)
+    myopf = opf.OPF(outdirect, False)
+    toc.take_article(document)
+    myopf.take_article(document)
+    ops_doc = ops.OPSPLoS(document, outdirect)
+    toc.write()
     myopf.write()
-    utils.epubZip(outdirect)
+    utils.epub_zip(outdirect)
 
 
 def epubcheck(epubname, config=None):
