@@ -20,10 +20,11 @@ class OPSPLoS(OPSMeta):
     def __init__(self, article, output_dir):
         OPSMeta.__init__(self)
         log.info('Initiating OPSPLoS')
+        #Set some initial hooks into the input article content
         self.article = article.root_tag
         self.metadata = article.metadata
         self.backmatter = article.metadata.backmatter
-        self.doi = article.getDOI()
+        self.doi = article.get_DOI()
         #From "10.1371/journal.pone.0035956" get "journal.pone.0335956"
         self.doi_frag = self.doi.split('10.1371/')[1]
         self.make_fragment_identifiers()
@@ -353,7 +354,7 @@ class OPSPLoS(OPSMeta):
             cur_aff_span = self.appendNewElement('span', affs_div)
             cur_aff_span.setAttribute('id', aff_id)
             if label_node:
-                label_text = utils.nodeText(label_node[0])
+                label_text = utils.nodeText(label_node[0]) + ' '
                 label_b = self.appendNewElementWithText('b', label_text, cur_aff_span)
             
             self.appendNewText(addr_line_text + ', ', cur_aff_span)
@@ -1001,7 +1002,7 @@ class OPSPLoS(OPSMeta):
                    'fn': self.main_frag,
                    'app': self.main_frag,
                    '': self.main_frag}
-        for x in self.getDescendantsByTagName(node, 'xref'):
+        for x in node.getElementsByTagName('xref'):
             x.tagName = 'a'
             x_attrs = x.getAllAttributes(remove=True)
             if 'ref-type' in x_attrs:
