@@ -15,6 +15,68 @@ import sys
 from openaccess_epub.utils.css import DEFAULT_CSS
 from openaccess_epub.utils.input import doi_input, url_input
 
+#Python documentation refers to this recipe for an OrderedSet
+#http://code.activestate.com/recipes/576694/
+import collections
+
+class OrderedSet(collections.MutableSet):
+
+    def __init__(self, iterable=None):
+        self.end = end = [] 
+        end += [None, end, end]         # sentinel node for doubly linked list
+        self.map = {}                   # key --> [key, prev, next]
+        if iterable is not None:
+            self |= iterable
+
+    def __len__(self):
+        return len(self.map)
+
+    def __contains__(self, key):
+        return key in self.map
+
+    def add(self, key):
+        if key not in self.map:
+            end = self.end
+            curr = end[1]
+            curr[2] = end[1] = self.map[key] = [key, curr, end]
+
+    def discard(self, key):
+        if key in self.map:        
+            key, prev, next = self.map.pop(key)
+            prev[2] = next
+            next[1] = prev
+
+    def __iter__(self):
+        end = self.end
+        curr = end[2]
+        while curr is not end:
+            yield curr[0]
+            curr = curr[2]
+
+    def __reversed__(self):
+        end = self.end
+        curr = end[1]
+        while curr is not end:
+            yield curr[0]
+            curr = curr[1]
+
+    def pop(self, last=True):
+        if not self:
+            raise KeyError('set is empty')
+        key = self.end[1][0] if last else self.end[2][0]
+        self.discard(key)
+        return key
+
+    def __repr__(self):
+        if not self:
+            return '%s()' % (self.__class__.__name__,)
+        return '%s(%r)' % (self.__class__.__name__, list(self))
+
+    def __eq__(self, other):
+        if isinstance(other, OrderedSet):
+            return len(self) == len(other) and list(self) == list(other)
+        return set(self) == set(other)
+
 def cache_location():
     '''Cross-platform placement of cached files'''
     if sys.platform == 'win32':  # Windows
@@ -233,6 +295,21 @@ def serializeText(fromnode, stringlist=None, sep=''):
     return sep.join(stringlist)
 
 
+#I wish to eventually shift all serializeText references to serialize_text
+def serialize_text(fromnode, stringlist=None, sep=''):
+    """
+    Recursively extract the text data from a node and it's children
+    """
+    if stringlist is None:
+        stringlist = []
+    for item in fromnode.childNodes:
+        if item.nodeType == item.TEXT_NODE and not item.data == '\n':
+            stringlist.append(item.data)
+        else:
+            serializeText(item, stringlist, sep)
+    return sep.join(stringlist)
+
+
 def nodeText(node):
     """
     This is to be used when a node may only contain text, numbers or special
@@ -309,7 +386,7 @@ def getFormattedNode(node):
     return clone
 
 
-def epubZip(outdirect):
+def epub_zip(outdirect):
     """Zips up the input file directory into an ePub file."""
     log.info('Zipping up the directory {0}'.format(outdirect))
     epub_filename = outdirect + '.epub'
@@ -335,20 +412,14 @@ def recursive_zip(zipf, directory, folder=''):
                           os.path.join(folder, item))
 
 
-def suggestedArticleTypes():
-    """
-    Returns a list of suggested values for article-type
-    """
-    #See http://dtd.nlm.nih.gov/publishing/tag-library/3.0/n-w2d0.html
-    s = ['abstract', 'addendum', 'announcement', 'article-commentary',
-         'book-review', 'books-received', 'brief-report', 'calendar',
-         'case-report', 'collection', 'correction', 'discussion',
-         'dissertation', 'editorial', 'in-brief', 'introduction', 'letter',
-         'meeting-report', 'news', 'obituary', 'oration',
-         'partial-retraction', 'product-review', 'rapid-communication',
-         'rapid-communication', 'reply', 'reprint', 'research-article',
-         'retraction', 'review-article', 'translation']
-    return(s)
+suggested_article_types = ['abstract', 'addendum', 'announcement',
+    'article-commentary','book-review', 'books-received', 'brief-report',
+    'calendar', 'case-report', 'collection', 'correction', 'discussion',
+    'dissertation', 'editorial', 'in-brief', 'introduction', 'letter',
+    'meeting-report', 'news', 'obituary', 'oration', 'partial-retraction',
+    'product-review', 'rapid-communication', 'rapid-communication', 'reply',
+    'reprint', 'research-article', 'retraction', 'review-article',
+    'translation']
 
 
 def initiateDocument(titlestring,
